;; Generated package description from graphql.el  -*- no-byte-compile: t -*-
(define-package "graphql" "0.1.2.0.20221128.50646" "GraphQL utilities" '((emacs "25")) :commit "b57b5ca5d2d0837e1fb4a4f30c051d5f3e643f0f" :authors '(("Sean Allred" . "code@seanallred.com")) :maintainer '("Sean Allred" . "code@seanallred.com") :keywords '("hypermedia" "tools" "lisp") :url "https://github.com/vermiculus/graphql.el")
